# Automating "Hello World" with ZAMM

Say you want to do the following task:

> Write a script hello.py that prints out "Hello world". Execute it.

You can do so by following these steps:

First, edit the file `hello.py`. It probably doesn't yet exist. Put code in it that accomplishes the task:

```
print("Hello world")
```

Now, execute it from the terminal:

```bash
$ python3 hello.py
Hello world
```

That's all! **Don't take any more steps** because the task is now done!
